# Devis pour des trucs géniaux

* pour **Le client**  
  1st Independance Street  
  SOMEWHERE
* par **Happy Dev**
* le 01/01/1970
* valide 30 jours

## Contexte

Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.

## Description de la prestation

Cubilia viverra senectus pellentesque pharetra cum inceptos semper, iaculis aptent a quam curabitur taciti egestas, primis enim vivamus condimentum diam dui. Lacus facilisis proin inceptos fames ultrices conubia tristique sociosqu iaculis dui mi, rhoncus ac nunc quisque interdum imperdiet vitae vulputate fusce.

## Livrables

Délai de livraison : **J + X ouvrés**

Montes non dui bibendum natoque dictum, nunc fermentum sollicitudin primis est massa, facilisi cubilia mus duis.

## Partie financière

Détail                                    | Charge  | Qté | Cumul
:-----------------------------------------|:-------:|:---:|:-----:
Faire un truc incroyable                  | ..h     | x   | ..h
Faire un truc encore mieux                | ..h     | y   | ..h
**Charge totale**                         ||              | **..h**
---                                       ||              |
Tarif horaire                             ||              | ..€/h
Total HT                                  ||              | ..€
TVA 20%\*                                 ||              | ..€
**Total TTC**                             ||              | **...€**

\*TVA récupérable à l'encaissement

## Modalités de règlements

Règlement par virement:

Ordre           | IBAN                              | BIC
----------------|-----------------------------------|---------
Happy Dev Paris | FR76 1027 8060 8200 0205 5370 166 | CMCIFR2A

Règlement à réception de la facture.  
Intérêts de retard: 6% par an + 40€/jour d'indemnité forfaitaire dès le premier jour de retard.

## Informations

Happy Dev Paris est une SAS à capital variable enregistrée au RCS de Paris. Elle est domiciliée au 15 rue des Halles à Paris (75001).

* *SIRET 81314060500011*
* *TVA intracommunautaire FR61812140606*

[CGV HAPPY DEV](https://drive.google.com/file/d/1KGpuki_53UhQ8SG_Se7EELPCPRirpFil/view)
